==> label_studio-1.13.1.tar.gz: label_studio-1.13.1/label_studio/core/feature_flags/stale_feature_flags.py <==
STALE_FEATURE_FLAGS = {
    'fflag_fix_front_leap_149_taxonomy_selected_true_short': True,
    'fflag_feat_all_dia_13_structured_data_support_short': False,
    'fflag_feat_front_optic_66_lazy_chart_evaluation_19092023_short': False,
    'fflag_feat_front_leap_187_video_seek_on_select_short': True,
    'fflag_feat_front_lsdv_5518_snap_to_pixel_130923_short': True,
    'fflag_fix_back_leap_24_tasks_api_optimization_05092023_short': False,
    'fflag_feat_optic_2_ensure_draft_saved_short': True,
    'fflag_fix_front_lsdv_5248_double_click_delay_280823_short': True,
    'fflag_feat_front_prod_e_111_annotator_workflow_control_short': True,
    'fflag_perf_back_lsdv_4695_update_prediction_query_to_use_direct_project_relation': True,
    'fflag_feat_front_lsdv_4620_outliner_optimization_310723_short': True,
    'fflag_fix_front_lsdv_4600_lead_time_27072023_short': False,
    'fflag_feat_front_lops_e_10_updated_ux_short': False,
    'fflag_fix_front_lsdv_4988_dynamic_no_label_120523_short': True,
    'fflag_fix_front_lsdv_4673_rect3point_relative_310523_short': True,
    'fflag_fix_back_lsdv_4648_annotator_filter_29052023_short': True,
    'fflag_feat_back_lsdv_5035_use_created_at_from_draft_for_annotation_256052023_short': True,
    'fflag_feat_front_lsdv_3025_outliner_filter_short': False,
    'fflag_feat_front_prod_309_choice_hint_080523_short': True,
    'fflag_fix_front_lsdv_4992_hide_all_regions_04052023_short': True,
    'ff_back_dev_4664_remove_storage_file_on_export_delete_29032023_short': False,
    'fflag_feat_front_lops_86_datasets_storage_edit_short': False,
    'fflag_fix_front_lsdv_4881_timeseries_points_missing_140423_short': True,
    'fflag_feat_front_lsdv_4832_new_ranker_tag_120423_short': True,
    'fflag_feat_front_lsdv_4712_skipduplicates_editing_110423_short': True,
    'fflag_fix_back_lsdv_4929_limit_exports_10042023_short': True,
    'fflag_feat_front_lsdv_3012_syncable_tags_070423_short': True,
    'fflag_feat_front_lsdv_4620_richtext_opimization_060423_short': True,
    'fflag_feat_front_lsdv_4661_full_uri_resolve_15032023_short': True,
    'fflag_fix_back_LSDV_4748_annotate_task_number_14032023_short': True,
    'fflag_feat_front_lsdv_4659_skipduplicates_060323_short': True,
    'fflag_feat_front_lsdv_4701_audio_default_decoder_ffmpeg_long': False,
    'fflag_fix_back_LSDV_961_project_list_09022023_short': True,
    'fflag_fix_font_lsdv_1148_hotkeys_namespaces_01022023_short': True,
    'fflag_fix_back_lsdv_1044_check_annotations_24012023_short': False,
    'fflag_feat_front_dev_4081_magic_wand_tool': True,
    'fflag_fix_front_dev_4075_taxonomy_overlap_281222_short': True,
    'fflag_fix_front_dev_3730_shortcuts_initial_input_22122022_short': True,
    'fflag_fix_front_dev_3734_hide_task_counter_131222_short': False,
    'ff_back_dev_3865_filters_anno_171222_short': True,
    'fflag_feat_front_dev_3873_labeling_ui_improvements_short': True,
    'fflag_feat_back_dev_3756_queue_enrollment_min_short': False,
    'fflag_fix_front_dev_3666_max_usages_on_region_creation_171122_short': True,
    'fflag_fix_front_dev_3617_taxonomy_memory_leaks_fix': True,
    'ff_back_dev_2915_storage_nginx_proxy_26092022_short': True,
    'fix_dev_3303_move_to_per_annotations_label_distribution': True,
    'fflag_fix_front_dev_3350_restrict_drawing_area_short': True,
    'fix_back_dev_3351_ml_validation_error_extension_short': False,
    'fflag_feat_front_dev_2984_dm_draggable_columns_short': True,
    'fflag_feat_front_dev_2461_audio_paragraphs_seek_chunk_position_short': True,
    'ff_feat_front_DEV_2576_undo_key_points_polygon_short': True,
    'fflag-feat-front-dev-2982-label-weights-settings': True,
    'ff_front_dev_2575_projects_list_performance_280622_short': True,
    'ff_front_dev_2432_auto_save_polygon_draft_210622_short': True,
    'ff_front_dev_2132_rotating_bounding_box': True,
    'ff_front_dev_2431_delete_polygon_points_080622_short': True,
    'ff_front_dev_2394_zoomed_transforms_260522_short': True,
    'ff_front_dev_2290_draft_in_annotation_history_short': True,
    'ff_dev_2128_html_in_labels_150422_short': True,
    'ff_dev_2100_clean_unnecessary_areas_140422_short': True,
    'ff_back_2070_inner_id_12052022_short': True,
    'ff_dev_2007_rework_choices_280322_short': True,
    'ff_dev_2007_dev_2008_dynamic_tag_children_250322_short': True,
    'ff_front_dev_1598_empty_toname_240222_short': True,
    'ff_front_dev_1372_visible_when_choice_unselected_11022022_short': True,
    'ff_front_dev_1621_interactive_mode_150222_short': True,
    'ff_front_DEV_1507_stuck_userpic_210122_short': True,
    'ff_front_dev_1566_shortcuts_in_results_010222_short': True,
    'ff_front_dev_1564_dev_1565_shortcuts_focus_and_cursor_010222_short': True,
    'ff_front_dev_1495_avatar_mess_210122_short': True,
    'ff_front_1170_outliner_030222_short': True,
    'ff_back_1587_email_notifications_310122_long': False,
    'ff_front_dev_1285_crosshair_wrong_zoom_140122_short': True,
}

==> label_studio-1.14.0.tar.gz: label_studio-1.14.0/label_studio/core/feature_flags/stale_feature_flags.py <==
STALE_FEATURE_FLAGS = {
    'fflag_fix_front_leap_149_taxonomy_selected_true_short': True,
    'fflag_feat_all_dia_13_structured_data_support_short': False,
    'fflag_feat_front_optic_66_lazy_chart_evaluation_19092023_short': False,
    'fflag_feat_front_leap_187_video_seek_on_select_short': True,
    'fflag_fix_back_leap_24_tasks_api_optimization_05092023_short': False,
    'fflag_feat_optic_2_ensure_draft_saved_short': True,
    'fflag_fix_front_lsdv_5248_double_click_delay_280823_short': True,
    'fflag_perf_back_lsdv_4695_update_prediction_query_to_use_direct_project_relation': True,
    'fflag_feat_front_lsdv_4620_outliner_optimization_310723_short': True,
    'fflag_fix_front_lsdv_4600_lead_time_27072023_short': False,
    'fflag_feat_front_lops_e_10_updated_ux_short': False,
    'fflag_fix_front_lsdv_4988_dynamic_no_label_120523_short': True,
    'fflag_fix_back_lsdv_4648_annotator_filter_29052023_short': True,
    'fflag_feat_back_lsdv_5035_use_created_at_from_draft_for_annotation_256052023_short': True,
    'fflag_feat_front_lsdv_3025_outliner_filter_short': False,
    'fflag_feat_front_prod_309_choice_hint_080523_short': True,
    'fflag_fix_front_lsdv_4992_hide_all_regions_04052023_short': True,
    'ff_back_dev_4664_remove_storage_file_on_export_delete_29032023_short': False,
    'fflag_feat_front_lops_86_datasets_storage_edit_short': False,
    'fflag_fix_front_lsdv_4881_timeseries_points_missing_140423_short': True,
    'fflag_feat_front_lsdv_4712_skipduplicates_editing_110423_short': True,
    'fflag_fix_back_lsdv_4929_limit_exports_10042023_short': True,
    'fflag_feat_front_lsdv_4620_richtext_opimization_060423_short': True,
    'fflag_feat_front_lsdv_4661_full_uri_resolve_15032023_short': True,
    'fflag_fix_back_LSDV_4748_annotate_task_number_14032023_short': True,
    'fflag_feat_front_lsdv_4659_skipduplicates_060323_short': True,
    'fflag_feat_front_lsdv_4701_audio_default_decoder_ffmpeg_long': False,
    'fflag_fix_back_LSDV_961_project_list_09022023_short': True,
    'fflag_fix_font_lsdv_1148_hotkeys_namespaces_01022023_short': True,
    'fflag_fix_back_lsdv_1044_check_annotations_24012023_short': False,
    'fflag_feat_front_dev_4081_magic_wand_tool': True,
    'fflag_fix_front_dev_4075_taxonomy_overlap_281222_short': True,
    'fflag_fix_front_dev_3730_shortcuts_initial_input_22122022_short': True,
    'ff_back_dev_3865_filters_anno_171222_short': True,
    'fflag_feat_front_dev_3873_labeling_ui_improvements_short': True,
    'fflag_feat_back_dev_3756_queue_enrollment_min_short': False,
    'fflag_fix_front_dev_3666_max_usages_on_region_creation_171122_short': True,
    'fflag_fix_front_dev_3617_taxonomy_memory_leaks_fix': True,
    'ff_back_dev_2915_storage_nginx_proxy_26092022_short': True,
    'fix_dev_3303_move_to_per_annotations_label_distribution': True,
    'fflag_fix_front_dev_3350_restrict_drawing_area_short': True,
    'fix_back_dev_3351_ml_validation_error_extension_short': False,
    'fflag_feat_front_dev_2984_dm_draggable_columns_short': True,
    'fflag_feat_front_dev_2461_audio_paragraphs_seek_chunk_position_short': True,
    'fflag-feat-front-dev-2982-label-weights-settings': True,
    'ff_front_dev_2432_auto_save_polygon_draft_210622_short': True,
    'ff_front_dev_2575_projects_list_performance_280622_short': True,
    'ff_front_dev_2431_delete_polygon_points_080622_short': True,
    'ff_front_dev_2290_draft_in_annotation_history_short': True,
    'ff_dev_2128_html_in_labels_150422_short': True,
    'ff_back_2070_inner_id_12052022_short': True,
    'ff_dev_2007_rework_choices_280322_short': True,
    'ff_front_dev_1495_avatar_mess_210122_short': True,
    'ff_front_1170_outliner_030222_short': True,
    'fflag_fix_front_lsdv_4620_memory_leaks_100723_short': False,
    'fflag_feat_optic_198_multi_select_users_short': True,
    'fflag_fix_back_lsdv_5410_temporary_disable_auto_inference_jobs_short': True,
    'fflag_feat_front_prod_292_archive_workspaces_short': True,
}
